function obj=step(varargin)
% STEP contains the physical characteristics (properties) of the object "step of potential energy" 
%   (by the next called simply as "step").  
%
%   obj=step(varargin) -- varargin states for various input arguments. 
%   Without any argument, returns none.
%   With one argument (one object step), returns the object.
%   With 6 arguments:
%       >> name  =  Step name
%       >> x     =  Position of the step on the Ox axis
%       >> Epe   =  Input potential energy
%       >> Eps   =  Output potential energy
%       >> ke    =  Input wavevector
%       >> ks    =  Output wavevector
%
%       << obj   =  Step object 
%
%   Olivier Pujol (2010)
%
switch (nargin)
    case 0
        obj.name=[];
        obj.x   =[];
        obj.Epe =[];
        obj.Eps =[];
        obj.ke  =[];
        obj.ks  =[];
        obj     =class(obj,'step');
    case 1
        if (isa(varargin{1},'step'))
            obj=varargin{1};
        else
            error('Object type is incorrect!');
        end
    case 6
        obj.name=varargin{1};
        obj.x   =varargin{2};
        obj.Epe =varargin{3};
        obj.Eps =varargin{4};
        obj.ke  =varargin{5};
        obj.ks  =varargin{6};
        obj=class(obj,'step');
    otherwise
        error('Bad numbers of input arguments!');
end
%
return;