function [sys,E]=OscHarm(L,Ep0,m,varargin)
% OscHarm returns the bound state energies of a physical object confined in an 
%  harmonic well of potentiel energy
%  
%  [sys,E]=OscHarm(L,Ep0,C,m,varargin) 
%					-- varargin states for various input arguments
%   >> L    = Well width (nm)
%   >> Ep0  = Well depth (eV) (Ep0 < 0)
%   >> m    = Physical object mass (with respect to electron mass) 
%   >> E    = Physical object energy values
%
% Olivier Pujol (2010)

%% Optional input arguments

switch length(varargin)
    case 0
        nx=100;                     % Default value of Ox point number
        nE=500;                     % Default value of energy value number
    case 1
        nx=varargin{1};             % Default value of Ox point number
        nE=500;                     % Default value of energy value number
    case 2
        nx=varargin{1};             % Default value of Ox point number
        nE=varargin{2};             % Default value of energy value number
    case 4
        nx=varargin{1};             % Value of Ox point number
        nE=varargin{2};             % Value of energy value number
        E=linspace(varargin{3},varargin{4},nE);     % Set of energy values
    otherwise
        ('Bad number of optional input arguments');
end

%% Potential energy

% Construction
x=linspace(-L/2,L/2,nx);     % Spatial domain
Epc=4*Ep0*(x/L).^2;          % Parabolic potential energy (origin is on well depth)

% Digitalization
[M,xt,Ep]=digitalization(x,Epc); 

% Energy values
if (length(varargin)~=4)
    E=linspace(min(Ep),Ep0,nE);   % Vector of energy values
end    

if (max(E)>Ep0)
    disp(' ');
    disp('Some E-values are out of bound state domain');
    disp(' ');
    return;
end

%% Bounded states

[sys,E]=Epot(M,xt,Ep,m,E);          % System
sysconf(sys,E);                     % Bound states

return;