function [M,xt,Ep]=digitalization(x,Epc)
% DIGITALIZATION transforms a continuous potential energy to a digitalized 
%   one made of various steps.
%
%   [M,xt,Ep]=digitalization(x,Epc)
%       >> x    = Coordinate on Ox axis
%       >> Epc  = Continuous potential energy
%       << M    = Name of a potential energy step
%       << xt   = Step position
%       << Ep   = Digitalized potential energy
%
%   Olivier Pujol (2010)
%
%% Name of the step constituting the digitalized potential energy

M=cell(1,(length(x)-1));
for n=1:length(x)-1
    M{n}=['M',num2str(n)];
end

%% Digitalization

[xs,Eps]=stairs(x,Epc);

% Step M positions
xs=xs-0.5*(x(2)-x(1));      % xs is translated from half Ox-step
xt=xs(2.*(1:length(x)-1));  % Selection of one value over two from xs(2)

% Step M height
Ep=Eps(2.*(1:length(x)-1)); % Same for Eps in order to get step M height

% Output potential energy must be imposed. 
% It is fixed to the last value of Epc 
Ep(length(x))=Epc(end);

%% Plotting

figure
plot(xs,Eps,'r',x,Epc,'b');
axis tight;
grid on;
box on;
set(gca,'Xminortick','on','Yminortick','on');
xlabel('x (nm)');
ylabel('Energy (eV)');
title('Potential energy');
%
return;