function [r,tau,phir,phitau]=factrtau(sys,TES)
% FACTRTAU gives the factors of reflection and transmission in terms of 
%   wave function complex amplitudes of a physical object which interacts 
%   with a potential energy.  
%   The phase (phi) of these complex factors are given between 0 and 2*pi.

%   [r,tau,phir,phitau]=factrtau(sys,TES)
%       >> sys      = System
%       >> TES      = Transfer matrix of the system
%       << r        = Factor of reflection
%       << tau      = Factor of transmission factor
%       << phir     = Phase shift at reflection
%       << phitau   = Phase shift at transmission
%
%   Olivier Pujol (2010)
%
if (nargin~=2),error('Bad number of input arguments!');end

nE=size(TES,2); % Number of energy values
r=nan(1,nE);
tau=nan(1,nE);
phir=nan(1,nE);
phitau=nan(1,nE);
%
for iE=1:nE
    r(iE)=-TES{iE}(2,1)/TES{iE}(2,2);
    tau(iE)=sqrt(sys{iE}{1}(3)/sys{iE}{1}(4))*(1/TES{iE}(2,2));
    phir(iE)=mod(angle(r(iE)),pi);
    phitau(iE)=mod(angle(tau(iE)),pi);
end
%
return;
